@@ -176,10 +176,7 @@ class IntArg(ArgType):
 class BoolArg(IntArg):
     def write_return(self, ptype, ownsreturn, info):
         info.varlist.add('int', 'ret')
-        info.varlist.add('PyObject', '*py_ret')
-        info.codeafter.append('    py_ret = ret ? Py_True : Py_False;\n'
-                              '    Py_INCREF(py_ret);\n'
-                              '    return py_ret;')
+        info.codeafter.append('    return PyBool_FromLong(ret);\n')
 
 class TimeTArg(ArgType):
     def write_param(self, ptype, pname, pdflt, pnull, info):
@@ -562,7 +559,7 @@ class AtomArg(IntArg):
         info.add_parselist('O', ['&py_' + pname], [pname])
     def write_return(self, ptype, ownsreturn, info):
         info.varlist.add('GdkAtom', 'ret')
-        info.codeafter.append('    return PyGdkAtom_New(ret);')
+        info.codeafter.append('    return PyString_FromString(gdk_atom_name(ret));')
 
 class GTypeArg(ArgType):
     gtype = ('    if ((%(name)s = pyg_type_from_object(py_%(name)s)) == 0)\n'
