@@ -71,10 +71,11 @@ void
 pyg_destroy_notify(gpointer user_data)
 {
     PyObject *obj = (PyObject *)user_data;
+    PyGILState_STATE state;
 
-    pyg_block_threads();
+    state = pyg_gil_state_ensure();
     Py_DECREF(obj);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
 }
 
 
@@ -95,10 +96,11 @@ static void
 pyobject_free(gpointer boxed)
 {
     PyObject *object = boxed;
+    PyGILState_STATE state;
 
-    pyg_block_threads();
+    state = pyg_gil_state_ensure();
     Py_DECREF(object);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
 }
 
 
@@ -330,14 +332,13 @@ pyg_object_set_property (GObject *object, guint property_id,
     PyObject *py_pspec, *py_value;
     PyGILState_STATE state;
 
-    pyg_block_threads();
-    state = PyGILState_Ensure();
+    state = pyg_gil_state_ensure();
 
     object_wrapper = pygobject_new(object);
 
     if (object_wrapper == NULL) {
-	pyg_unblock_threads();
-	g_return_if_fail(object_wrapper != NULL);
+	pyg_gil_state_release(state);
+	return;
     }
 
     py_pspec = pyg_param_spec_new(pspec);
@@ -355,8 +356,7 @@ pyg_object_set_property (GObject *object, guint property_id,
     Py_DECREF(py_pspec);
     Py_DECREF(py_value);
 
-    PyGILState_Release(state);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
 }
 
 static void
@@ -367,14 +367,13 @@ pyg_object_get_property (GObject *object, guint property_id,
     PyObject *py_pspec;
     PyGILState_STATE state;
 
-    pyg_block_threads();
-    state = PyGILState_Ensure();
+    state = pyg_gil_state_ensure();
 
     object_wrapper = pygobject_new(object);
 
     if (object_wrapper == NULL) {
-	pyg_unblock_threads();
-	g_return_if_fail(object_wrapper != NULL);
+	pyg_gil_state_release(state);
+	return;
     }
 
     py_pspec = pyg_param_spec_new(pspec);
@@ -387,8 +386,7 @@ pyg_object_get_property (GObject *object, guint property_id,
     Py_DECREF(py_pspec);
     Py_XDECREF(retval);
     
-    PyGILState_Release(state);
-    pyg_unblock_threads();        
+    pyg_gil_state_release(state);
 }
 
 static void
@@ -1259,8 +1257,7 @@ handler_marshal(gpointer user_data)
 
     g_return_val_if_fail(user_data != NULL, FALSE);
 
-    pyg_block_threads();
-    state = PyGILState_Ensure();
+    state = pyg_gil_state_ensure();
 
     tuple = (PyObject *)user_data;
     ret = PyObject_CallObject(PyTuple_GetItem(tuple, 0),
@@ -1273,8 +1270,7 @@ handler_marshal(gpointer user_data)
 	Py_DECREF(ret);
     }
     
-    PyGILState_Release(state);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
 
     return res;
 }
@@ -1364,8 +1360,7 @@ iowatch_marshal(GIOChannel *source, GIOCondition condition, gpointer user_data)
 
     g_return_val_if_fail(user_data != NULL, FALSE);
 
-    pyg_block_threads();
-    state = PyGILState_Ensure();
+    state = pyg_gil_state_ensure();
 
     tuple = (PyObject *)user_data;
     func = PyTuple_GetItem(tuple, 0);
@@ -1385,8 +1380,7 @@ iowatch_marshal(GIOChannel *source, GIOCondition condition, gpointer user_data)
 	Py_DECREF(ret);
     }
 
-    PyGILState_Release(state);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
 
     return res;
 }
@@ -1442,14 +1436,11 @@ static PyObject *
 pyg_source_remove(PyObject *self, PyObject *args)
 {
     guint tag;
-    PyObject *ret;
 
     if (!PyArg_ParseTuple(args, "i:source_remove", &tag))
 	return NULL;
 
-    ret = g_source_remove(tag) ? Py_True : Py_False;
-    Py_INCREF(ret);
-    return ret;
+    return PyBool_FromLong(g_source_remove(tag));
 }
 
 static PyObject *
@@ -1467,6 +1458,31 @@ pyg_main_context_default (PyObject *unused)
 
 }
 
+static int
+pyg_enable_threads (void)
+{
+#ifndef DISABLE_THREADING
+    PyEval_InitThreads();
+    if (!g_threads_got_initialized)
+	g_thread_init(NULL);
+    pygobject_api_functions.threads_enabled = TRUE;
+    return 0;
+#else
+    PyErr_SetString(PyExc_RuntimeError,
+                    "pygtk threading disabled at compile time");
+    return -1;
+#endif
+}
+
+static PyObject *
+pyg_threads_init (PyObject *unused)
+{
+    if (pyg_enable_threads())
+        return NULL;
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyMethodDef pygobject_functions[] = {
     { "type_name", pyg_type_name, METH_VARARGS },
     { "type_from_name", pyg_type_from_name, METH_VARARGS },
@@ -1484,6 +1500,7 @@ static PyMethodDef pygobject_functions[] = {
     { "io_add_watch", (PyCFunction)pyg_io_add_watch, METH_VARARGS|METH_KEYWORDS },
     { "source_remove", pyg_source_remove, METH_VARARGS },
     { "main_context_default", (PyCFunction)pyg_main_context_default, METH_NOARGS },
+    { "threads_init", (PyCFunction)pyg_threads_init, METH_NOARGS },
     { NULL, NULL, 0 }
 };
 
@@ -1620,8 +1637,7 @@ pyg_error_check(GError **error)
 	PyObject *exc_instance;
 	PyObject *d;
 	
-	pyg_block_threads();
-	state = PyGILState_Ensure();
+	state = pyg_gil_state_ensure();
 	
 	exc_instance = PyObject_CallFunction(gerror_exc, "z",
 					     (*error)->message);
@@ -1643,8 +1659,7 @@ pyg_error_check(GError **error)
 	Py_DECREF(exc_instance);
 	g_clear_error(error);
 	
-	PyGILState_Release(state);
-	pyg_unblock_threads();
+	pyg_gil_state_release(state);
 	
 	return TRUE;
     }
@@ -1797,7 +1812,10 @@ struct _PyGObject_Functions pygobject_api_functions = {
   
   &PyGFlags_Type,
   pyg_flags_add,
-  pyg_flags_from_gtype
+  pyg_flags_from_gtype,
+
+  FALSE, /* threads_enabled */
+  pyg_enable_threads
 };
 
 #define REGISTER_TYPE(d, type, name) \
@@ -1821,16 +1839,10 @@ initgobject(void)
 
     PyGTypeWrapper_Type.ob_type = &PyType_Type;
     PyGParamSpec_Type.ob_type = &PyType_Type;
-
+    
     m = Py_InitModule("gobject", pygobject_functions);
     d = PyModule_GetDict(m);
 
-#ifdef ENABLE_PYGTK_THREADING
-    PyEval_InitThreads();
-    if (!g_threads_got_initialized)
-	g_thread_init(NULL);
-#endif
-
     g_type_init();
 
     PY_TYPE_OBJECT = g_boxed_type_register_static("PyObject",
